#
# spec file for package OpenSubdiv
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019-2020 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkgver 3_6_0
%define libname libosdCPU%{pkgver}
Name:           OpenSubdiv
Version:        3.6.0
Release:        1.4
Summary:        Subdivision surface evaluation library
License:        Apache-2.0
Group:          Productivity/Graphics/Visualization/Raytracers
URL:            https://graphics.pixar.com/opensubdiv/docs/intro.html
Source:         https://github.com/PixarAnimationStudios/%{name}/archive/v%{pkgver}.tar.gz#/%{name}-%{pkgver}.tar.gz
Patch0:         remove-rpath-fiddling.diff
BuildRequires:  cmake >= 2.8.6
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)

%description
%{name} is a set of libraries that implement subdivision surface
(subdiv) evaluation on massively parallel CPU and GPU architectures.

%package -n %{libname}
Summary:        Subdivision surface evaluation library
Group:          System/Libraries

%description -n %{libname}
%{name} is a set of libraries that implement subdivision surface
(subdiv) evaluation on massively parallel CPU and GPU architectures.
This code path is optimized for drawing deforming surfaces with
static topology at interactive framerates.

%{name} is an API for use by 3rd party digital content creation
tools. It is not an application, nor a tool that can be used directly
to create digital assets.

%package devel
Summary:        Development files for OpenSubdiv
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%autosetup -p0 -n %{name}-%{pkgver}

# work around linking glitch
sed -i 's/${PLATFORM_GPU_LIBRARIES}/${PLATFORM_GPU_LIBRARIES} ${CMAKE_DL_LIBS}/' opensubdiv/CMakeLists.txt

%build
# sse options only on supported archs
%ifarch x86_64
sseflags='-msse -msse2'
%endif

%cmake \
    -DCMAKE_C_FLAGS:STRING="$CFLAGS %{optflags} -fPIC ${sseflags}" \
    -DCMAKE_CXX_FLAGS:STRING="$CXXFLAGS %{optflags} -fPIC ${sseflags}" \
    -DCMAKE_LIBDIR_BASE=%{_libdir} \
    -DNO_PTEX=1 \
    -DNO_DOC=1 \
    -DNO_CUDA=1 \
    -DNO_CLEW=1 \
    -DNO_OPENCL=1 \
    -DNO_TUTORIALS=1 \
    -DNO_REGRESSION=1 \
    -DNO_EXAMPLES=1 \
    -DGLEW_LOCATION=%{_prefix} \
    -DGLFW_LOCATION=%{_prefix} \
    -DOpenGL_GL_PREFERENCE=GLVND

%cmake_build

%install
%cmake_install
# remove unused build artefact
rm %{buildroot}%{_libdir}/*.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE.txt
%doc NOTICE.txt README.md
%{_libdir}/*.so.*

%files devel
%{_includedir}/opensubdiv
%{_libdir}/*.so
%dir %{_libdir}/cmake/OpenSubdiv/
%{_libdir}/cmake/OpenSubdiv/OpenSubdivConfig.cmake
%{_libdir}/cmake/OpenSubdiv/OpenSubdivConfigVersion.cmake
%{_libdir}/cmake/OpenSubdiv/OpenSubdivTargets-relwithdebinfo.cmake
%{_libdir}/cmake/OpenSubdiv/OpenSubdivTargets.cmake

%changelog
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 3.6.0:
  See:
  * https://graphics.pixar.com/opensubdiv/docs/release_35.html
  * https://graphics.pixar.com/opensubdiv/docs/release_36.html
- Drop OpenSubdiv-pr1234-tbb2021.patch
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov 23 2021 Ben Greiner <code@bnavigator.de>
- Update to version 3.4.4 (Feb 2021)
  + Release 3.4.4 is a minor release including bug fixes and
    configuration improvements
  + Changes
  * The "master" branch on GitHub has been renamed "release"
    (GitHub #1218 #1219)
  * The CMake configuration has been updated to allow use as a
    sub-project (GitHub #1206)
  * Removed obsolete references to hbr from examples/farViewer
    (GitHub #1217)
  + Bug Fixes
  * Fixed bug with sparse PatchTables and irregular face-varying
    seams (GitHub #1203)
  * Fixed loss of precision when using double precision stencil
    tables (GitHub #1207)
  * Fixed reset of Far::TopologyRefiner::GetMaxLevel() after call
    to Unrefine() (GitHub #1208)
  * Fixed linking with -ldl on unix systems (GitHub #1196)
  * Fixed naming and installation of macOS frameworks (GitHub
    [#1194] #1201)
  * Fixed GL version and extension processing and dynamic loading
    on macOS (GitHub #1216)
  * Fixed FindDocutils.cmake to be more robust (GitHub #1213
    [#1220])
  * Fixed errors using build_scripts/build_osd.py with Python3
    (GitHub #1206)
- Add OpenSubdiv-pr1234-tbb2021.patch -- support oneTBB 2021
  * gh#PixarAnimationStudios/OpenSubdiv#1234
  * boo#1192994
* Mon Jul  6 2020 Hans-Peter Jansen <hpj@urpla.net>
- Add patch remove-rpath-fiddling.diff in order to avoid build
  issues with TW.
* Fri Apr 24 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 3.4.3 (April 2020):
  + Changes
  * GLEW is no longer required by default (GitHub #1183 #1184)
  * Removed false Ptex link dependency from libosdCPU (GitHub
    [#1174])
  * Removed false GLFW link dependency from DX11 and Metal
    examples (GitHub #1178)
  * Removed link dependency on unused TBB libraries (GitHub
    [#1064])
  * Added option to disable building of dynamic shared libraries
    (GitHub #1169)
  * Added new tutorial for Far::LimitStencilTable (GitHub #1176)
  * Updated use of EXT_direct_state_access to
    ARB_direct_state_access (GitHub #1184)
  * Fixed C++ strict aliasing warnings (GitHub #1182)
  * Fixed MSVC warnings in example code (GitHub #1158 #1172)
  * Fixed compatibility with Visual Studio 2019 (GitHub #1173
    [#1189])
  * Fixed CMake CMP0054 warnings (GitHub #1180)
  * Added prefix to OpenSubdiv CMake macros (GitHub #1157)
  * Moved utilities in examples/common to regression/common
    (GitHub #1167)
  * Minor fixes to Far tutorials (GitHub #1175 #1177)
  * Switched to Azure Pipelines for continuous integration
    testing instead of Travis-CI and AppVeyor (GitHub #1168
    [#1190])
  + Bug Fixes
  * Fixed selective boundary interpolation for case
    Sdc::Options::VTX_BOUNDARY_NONE (GitHub #1170 #1171)
  * Fixed static library linking to address missing symbols
    (GitHub #1192)
  * Additional fixes for dynamic and static linking (GitHub
    [#1193])
- Add workaround to fix linking libosdGPU, which is missing -ldl
* Sun Sep 22 2019 Hans-Peter Jansen <hpj@urpla.net>
- Use tbb-devel BuildRequires instead of cmake(TBB), the latter is not
  available in Leap 15.x
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid forcing SSE/SSE2 on %%ix86, it is not guaranteed to exist.
- Trim bias and redundancies from descriptions.
- RPM group/category fixes.
* Wed Jul 10 2019 Hans-Peter Jansen <hpj@urpla.net>
- version 3.4.0: initial build
